Learn R Programming

hash (version 1.0.3)

.get: Get values from a hash

Description

Returns the values of a hash. By default, it attempts to simplify the results as a vector ( or matrixs ) if possible.

This funciton is hidden and should not normally be needed. The accessor methods: $, [ and [[ provide for much more convenient access.

See hash

Usage

.get(hash, keys, drop=TRUE, ... )

Arguments

Value

A list or vector of hash values in

Details

Takes the keys, coerces them to valid keys and returns the associated values in a form dictated by ... arguments supllied to sapply such as simplify or USE.NAMES. See sapply for details.

See Also

See Also hash, .set, sapply

Examples

Run this code
h <- hash( letters, 1:26 )
 .get( h, "b" )  # 2

Run the code above in your browser using DataLab